@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2013 Open-Xchange, Inc.
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -85,14 +85,12 @@ import com.openexchange.file.storage.FileStoragePermission;
 import com.openexchange.file.storage.Quota;
 import com.openexchange.file.storage.Quota.Type;
 import com.openexchange.file.storage.TypeAware;
+import com.openexchange.file.storage.composition.FileStorageCapability;
 import com.openexchange.file.storage.composition.FolderID;
 import com.openexchange.file.storage.composition.IDBasedFileAccess;
 import com.openexchange.file.storage.composition.IDBasedFileAccessFactory;
 import com.openexchange.file.storage.composition.IDBasedFolderAccess;
 import com.openexchange.file.storage.composition.IDBasedFolderAccessFactory;
-import com.openexchange.file.storage.composition.IDBasedIgnorableVersionFileAccess;
-import com.openexchange.file.storage.composition.IDBasedRandomFileAccess;
-import com.openexchange.file.storage.composition.IDBasedSequenceNumberProvider;
 import com.openexchange.file.storage.search.FileNameTerm;
 import com.openexchange.i18n.tools.StringHelper;
 import com.openexchange.java.Strings;
@@ -184,7 +182,7 @@ public class DriveStorage {
         copiedFile.setLastModified(new Date());
         copiedFile.setVersion("1");
         copiedFile.setFileMIMEType(sourceFile.getFileMIMEType());
-        List<Field> fileFields = Arrays.asList(new Field[] { Field.FILENAME, Field.TITLE, Field.FOLDER_ID, Field.LAST_MODIFIED });
+        List<Field> fileFields = Arrays.asList(new Field[] { Field.FILENAME, Field.TITLE, Field.FOLDER_ID, Field.LAST_MODIFIED, Field.VERSION });
         if (session.isTraceEnabled()) {
             session.trace(this.toString() + "cp " + combine(getPath(sourceFile.getFolderId()), sourceFile.getFileName()) + " " +
                 combine(targetPath, targetFileName));
@@ -505,11 +503,10 @@ public class DriveStorage {
         if (null == folderIDs || 0 == folderIDs.size()) {
             return Collections.emptyMap();
         }
-        IDBasedFileAccess fileStorageFileAccess = getFileAccess();
-        if (false == IDBasedSequenceNumberProvider.class.isInstance(fileStorageFileAccess)) {
+        if (false == supports(FileStorageCapability.SEQUENCE_NUMBERS)) {
             throw new UnsupportedOperationException("IDBasedSequenceNumberProvider is needed");
         }
-        return ((IDBasedSequenceNumberProvider)fileStorageFileAccess).getSequenceNumbers(folderIDs);
+        return getFileAccess().getSequenceNumbers(folderIDs);
     }
 
     public InputStream getDocument(File file) throws OXException {
@@ -723,7 +720,7 @@ public class DriveStorage {
      */
     public FileStorageFolder getTrashFolder() throws OXException {
         if (null == trashFolder) {
-            return getFolderAccess().getTrashFolder(rootFolderID.toUniqueID());
+            trashFolder = getFolderAccess().getTrashFolder(rootFolderID.toUniqueID());
         }
         return trashFolder;
     }
@@ -792,10 +789,14 @@ public class DriveStorage {
     private SearchIterator<File> getDocuments(String folderID, String filename, List<Field> fields) throws OXException {
         if (null == filename) {
             return getDocuments(folderID, fields);
+        } else if (supports(FileStorageCapability.SEARCH_BY_TERM)) {
+            return getFileAccess().search(Collections.singletonList(folderID), new FileNameTerm(filename, false, false),
+                null != fields ? fields : DriveConstants.FILE_FIELDS, null, SortDirection.DEFAULT,
+                FileStorageFileAccess.NOT_SET, FileStorageFileAccess.NOT_SET);
+        } else {
+            return getFileAccess().search(filename, fields, folderID, null, SortDirection.DEFAULT,
+                FileStorageFileAccess.NOT_SET, FileStorageFileAccess.NOT_SET);
         }
-        return getFileAccess().search(Collections.singletonList(folderID), new FileNameTerm(filename, false, false),
-            null != fields ? fields : DriveConstants.FILE_FIELDS, null, SortDirection.DEFAULT,
-            FileStorageFileAccess.NOT_SET, FileStorageFileAccess.NOT_SET);
     }
 
     private SearchIterator<File> getDocuments(String folderID, List<Field> fields) throws OXException {
@@ -815,7 +816,7 @@ public class DriveStorage {
                     for (FileStorageFolder folder : subfolders) {
                         String normalizedFolderName = PathNormalizer.normalize(folder.getName());
                         knownFolders.remember(currentPath + normalizedFolderName, folder);
-                        if (normalizedName.equals(normalizedFolderName)) {
+                        if (normalizedName.equalsIgnoreCase(normalizedFolderName)) {
                             existingFolder = folder;
                         }
                     }
@@ -974,38 +975,47 @@ public class DriveStorage {
     }
 
     /**
-     * Gets a value indicating if the underlying storage allows to perform random access file operations or not.
+     * Gets a value indicating if the underlying storage system supports one or more capabilities or not.
      *
-     * @return <code>true</code> if random file access is supported, <code>false</code>, otherwise
-     * @throws OXException
+     * @return <code>true</code> if all capabilities are supported, <code>false</code>, otherwise
      */
-    public boolean isRandomFileAccess() throws OXException {
-        return IDBasedFileAccess.class.isInstance(getFileAccess()) &&
-            ((IDBasedRandomFileAccess)getFileAccess()).supportsRandomFileAccess(rootFolderID.getService(), rootFolderID.getAccountId());
+    public boolean supports(FileStorageCapability...capabilities) throws OXException {
+        return getFileAccess().supports(rootFolderID.getService(), rootFolderID.getAccountId(), capabilities);
     }
 
-    /**
-     * Gets a value indicating if the underlying storage allows to ignore versions when updating or not.
-     *
-     * @return <code>true</code> if ignorable versions are supported, <code>false</code>, otherwise
-     * @throws OXException
-     */
-    public boolean isIgnorableVersionFileAccess() throws OXException {
-        return IDBasedIgnorableVersionFileAccess.class.isInstance(getFileAccess()) &&
-            ((IDBasedIgnorableVersionFileAccess)getFileAccess())
-            .supportsIgnorableVersion(rootFolderID.getService(), rootFolderID.getAccountId());
-    }
-
-    /**
-     * Gets a value indicating whether folder sequence numbers are supported by the underlying storage or not.
-     *
-     * @return <code>true</code> if sequence numbers are supported, <code>false</code>, otherwise
-     * @throws OXException
-     */
-    public boolean supportsFolderSequenceNumbers() throws OXException {
-        return IDBasedSequenceNumberProvider.class.isInstance(getFileAccess()) &&
-            ((IDBasedSequenceNumberProvider)getFileAccess()).supportsSequenceNumbers(rootFolderID.toUniqueID());
-    }
+//    /**
+//     * Gets a value indicating if the underlying storage allows to perform random access file operations or not.
+//     *
+//     * @return <code>true</code> if random file access is supported, <code>false</code>, otherwise
+//     * @throws OXException
+//     */
+//    public boolean isRandomFileAccess() throws OXException {
+//        return IDBasedFileAccess.class.isInstance(getFileAccess()) &&
+//            ((IDBasedRandomFileAccess)getFileAccess()).supportsRandomFileAccess(rootFolderID.getService(), rootFolderID.getAccountId());
+//    }
+//
+//    /**
+//     * Gets a value indicating if the underlying storage allows to ignore versions when updating or not.
+//     *
+//     * @return <code>true</code> if ignorable versions are supported, <code>false</code>, otherwise
+//     * @throws OXException
+//     */
+//    public boolean isIgnorableVersionFileAccess() throws OXException {
+//        return IDBasedIgnorableVersionFileAccess.class.isInstance(getFileAccess()) &&
+//            ((IDBasedIgnorableVersionFileAccess)getFileAccess())
+//            .supportsIgnorableVersion(rootFolderID.getService(), rootFolderID.getAccountId());
+//    }
+//
+//    /**
+//     * Gets a value indicating whether folder sequence numbers are supported by the underlying storage or not.
+//     *
+//     * @return <code>true</code> if sequence numbers are supported, <code>false</code>, otherwise
+//     * @throws OXException
+//     */
+//    public boolean supportsFolderSequenceNumbers() throws OXException {
+//        return IDBasedSequenceNumberProvider.class.isInstance(getFileAccess()) &&
+//            ((IDBasedSequenceNumberProvider)getFileAccess()).supportsSequenceNumbers(rootFolderID.toUniqueID());
+//    }
 
     @Override
     public String toString() {
