@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2013 Open-Xchange, Inc.
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -139,14 +139,8 @@ public class FileActionExecutor extends BatchActionExecutor<FileVersion> {
                 LOG.warn("Got exception during server-side execution of download action: {}\nSession: {}, path: {}, action: {}",
                     e.getMessage(), session, path, action);
                 if (DriveUtils.indicatesQuotaExceeded(e)) {
-                    /*
-                     * quota exceeded
-                     */
                     addNewActionsForClient(DriveUtils.handleQuotaExceeded(session, e, path, action.getVersion(), action.getNewVersion()));
-                } else if ("IFO-0100".equals(e.getErrorCode())) {
-                    /*
-                     * database fields (filename/title/comment?) too long - put into quarantine to prevent repeated errors
-                     */
+                } else if (DriveUtils.indicatesFailedSave(e)) {
                     addNewActionForClient(new ErrorFileAction(null, action.getNewVersion(), null, path, e, true));
                 } else {
                     throw e;
@@ -159,10 +153,7 @@ public class FileActionExecutor extends BatchActionExecutor<FileVersion> {
             } catch (OXException e) {
                 LOG.warn("Got exception during server-side execution of edit action: {}\nSession: {}, path: {}, action: {}",
                     e.getMessage(), session, path, action);
-                if ("IFO-0100".equals(e.getErrorCode())) {
-                    /*
-                     * database fields (filename/title/comment?) too long - put into quarantine to prevent repeated errors
-                     */
+                if (DriveUtils.indicatesFailedSave(e)) {
                     addNewActionForClient(new ErrorFileAction(null, action.getNewVersion(), null, path, e, true));
                 } else {
                     throw e;
